@@ -30,9 +30,16 @@
 
 #include "PsxCommon.h"
 #include "Sio.h"
-#include "gpuAPI/newGPU/newGPU.h"
-
-
+#ifdef MAEMO_CHANGES
+#include "minimal.h"
+#endif
+ 
+ #ifdef OPENGL_ESM
+	#include "gpu-gles/gpuPlugin.h"
+#else
+	#include "gpuAPI/newGPU/newGPU.h"
+#endif
+ 
 #ifdef IPHONE
 extern const char* get_resource_path(char* file);
 extern const char* get_documents_path(char* file);
@@ -126,7 +133,8 @@ int main(int argc, char *argv[])
 	Config.Sio = 0;
 	Config.SpuIrq = 0;
 	Config.VSyncWA = 0;
-#ifndef PEOPS_GPU
+
+#if !(defined(PEOPS_GPU)|| defined(OPENGL_ESM))
 	displayFrameInfo = 0;
 #endif
 bool fullscreen=false;
@@ -138,12 +146,13 @@ accel_move=false;
 		else if (!strcmp(argv[i], "-load")) loadst = argv[++i];
 		else if (!strcmp(argv[i], "-nosound")) iSoundMuted = 1;
 		else if (!strcmp(argv[i], "-fullscreen")) fullscreen = true;
-#ifndef PEOPS_GPU
+#if !(defined(PEOPS_GPU)|| defined(OPENGL_ESM))
 		else if (!strcmp(argv[i], "-showfps")) displayFrameInfo = 1;
 #endif
 #if defined(ENABLE_GPU_PRIM_STATS) || defined(ENABLE_GPU_PROFILLER)
 		else if (!strcmp(argv[i], "-gpustats")) displayGpuStats = 1;
 #endif
+		#if !(defined(PEOPS_GPU)|| defined(OPENGL_ESM))
 		else if (!strcmp(argv[i], "-frameskip"))
 		{
 			int skipValue = atoi(argv[++i]);
@@ -157,6 +166,7 @@ accel_move=false;
 		{
 		autoSkip=true;
 		} 
+		#endif
 		else if (!strcmp(argv[i], "-cyclemult"))
 		{
 			int cycleValue = atoi(argv[++i]);
@@ -165,7 +175,7 @@ accel_move=false;
 				PsxCycleMult = cycleValue;
 			}
 		}
-		#ifndef PEOPS_GPU
+		#if !(defined(PEOPS_GPU)|| defined(OPENGL_ESM))
 		else if (!strcmp(argv[i], "-ilace"))
 		{
 			int iLace = atoi(argv[++i]);
@@ -212,7 +222,7 @@ accel_move=false;
 	gp2x_init(1000, 16, 11025, 16, 1, 60, 1);
 
 #ifdef MAEMO_CHANGES
-	hildon_init (&argc, &argv,file,loadst,fullscreen);
+	hildon_init2(&argc, &argv,file,loadst,fullscreen);
 #endif
 
 	if (SysInit() == -1) return 1;
@@ -248,12 +258,12 @@ printf ("Started\n");
 
 #ifdef MAEMO_CHANGES
 
-#ifndef PEOPS_GPU
+#if !(defined(PEOPS_GPU)|| defined(OPENGL_ESM))
 	printf(
 		"CdromFile: %s\n"
 
 		"Show FPS                 %s\n"
-#endif
+
 #if defined(ENABLE_GPU_PRIM_STATS) || defined(ENABLE_GPU_PROFILLER)
 		"Show GPU Stats           %s\n"
 #endif
@@ -288,8 +298,8 @@ printf ("Started\n");
 		(fullscreen == true ? "ON" : "OFF"),
 		(accel_move==true ? "ON":"OFF")
 	);
-	#endif
-
+#endif
+#endif
 
 	psxCpu->Execute();
 	return 0;
@@ -380,21 +390,15 @@ void SysUpdate() {
 void SysRunGui() {
 }
 
+
+
 void SysMessage(char* fmt, ...) {
 #ifdef EMU_LOG
-
-	va_list list;
-
-	va_start(list, fmt);
-	vsprintf(__sysmsg, fmt, list);
-	va_end(list);
-
-	__sysmsg[127]=0;
-
-	if (Config.PsxOut) printf ("%s\n", __sysmsg);
-	//SysPrintf("%s", __sysmsg);
-	fprintf(emuLog, "%s\r\n", __sysmsg);
-	fflush(emuLog);
+  char buffer[256];
+  va_list args;
+  va_start (args, fmt);
+  vsprintf (buffer,fmt, args);
+  perror (buffer);
+  va_end (args);
 #endif
 }
-
