@@ -1,17 +1,17 @@
-#include <gtk/gtk.h>
-#include <glib.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <hildon/hildon.h>
+//#include <gdk/gdkx.h>
+//#include <gdk/gdk.h>
+
 #include <string.h>
-#include "minimal.h"
 #include <pthread.h>
 #include <time.h>
 
+#include "minimal.h"
+
+
 GdkImage *image;
 HildonAnimationActor *actor;
 GtkWidget *window, *drawing;
-
+GtkWidget* windowG;
 #define X_RES           800
 #define Y_RES           480
 #define D_WIDTH			640
@@ -22,6 +22,7 @@ GtkWidget *window, *drawing;
 int screen_size;
 unsigned short* screenbuffer = NULL;
 
+
 unsigned long keys = 0;
 pthread_t accel;
 int sens,y_def;
@@ -45,10 +46,9 @@ window_key_proxy (GtkWidget *widget,
 		     gpointer user_data)
 {
 	unsigned long key = 0;
-	
-if (keymap[event->keyval]==-1)return;
-
-switch(keymap[event->keyval]){
+switch(keymap[event->hardware_keycode]){
+	case -1:
+		return; break;
 	case 0:
 			key = GP2X_LEFT;break;
 	case 1:
@@ -135,7 +135,7 @@ switch(keymap[event->keyval]){
 }
 
 
-void hildon_init(int *argc, char ***argv,char *fl,char* lst,bool fscreen)
+void hildon_init2(int *argc, char ***argv,char *fl,char* lst,bool fscreen)
 {
 fullscreen=fscreen;
 	file=fl;
@@ -171,6 +171,8 @@ fullscreen=fscreen;
 	}
 	
 	
+
+	
 	gtk_init (argc, argv);
 	window = hildon_stackable_window_new ();
 	gtk_widget_realize (window);
@@ -192,16 +194,23 @@ fullscreen=fscreen;
 	
 	}
 	hildon_animation_actor_set_parent (actor, GTK_WINDOW (window));
-
+#ifndef OPENGL_ESM
 	drawing = gtk_image_new ();
 	gtk_container_add (GTK_CONTAINER (actor), drawing);
-
+#endif
 	gtk_widget_show_all (GTK_WIDGET (actor));
+	gdk_window_set_back_pixmap(((GtkWidget*)actor)->window, NULL, FALSE);
+    gtk_widget_set_app_paintable((GtkWidget*)actor,TRUE);
+	GTK_WIDGET_UNSET_FLAGS (actor, GTK_DOUBLE_BUFFERED);
 	gtk_widget_show_all (GTK_WIDGET (window));
+	
+	windowG=(GtkWidget*)actor;
+
 }
 
 void gp2x_change_res(int w, int h)
 {
+#ifndef OPENGL_ESM
 	if (Config.PsxOut)SysPrintf ("PSX resolution change: %dx%d", w, h);
 	
 	if (w <= 0 || h <= 0)
@@ -230,7 +239,7 @@ void gp2x_change_res(int w, int h)
 				(gdouble)F_WIDTH / (gdouble)w,
 				(gdouble)F_HEIGHT / (gdouble)h
 	);}
-	
+#endif
 }
 
 unsigned long gp2x_joystick_read(void)
@@ -245,8 +254,10 @@ unsigned long gp2x_joystick_read(void)
 
 void gp2x_video_RGB_clearscreen16(void)
 {
+	#ifndef OPENGL_ESM
 	if (gp2x_screen16 && screen_size)
 		memset(gp2x_screen16, 0, screen_size);
+#endif
 }
 
 void updateScreen()
